@@ -195,7 +195,7 @@ from ae.gui_app import (
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.1.27'
+__version__ = '0.1.28'
 
 
 register_package_translations()
@@ -803,7 +803,7 @@ class TourBase:
         self._saved_app_states = deepcopy(main_app.retrieve_app_states())
 
     def load_page_data(self):
-        """ load page before switching to it. """
+        """ load page before switching to it (and maybe reload after preparing app flow and before setup of layout). """
         page_idx = self.page_idx
         page_cnt = len(self.page_ids)
         assert 0 <= page_idx < page_cnt, f"page_idx ({page_idx}) has to be greater zero and less than {page_cnt}"
@@ -854,16 +854,6 @@ class TourBase:
 
         self.setup_page()
 
-    def remove_page(self, page_id: str):
-        """ remove tour page in teardown page process.
-
-        :param page_id:         id of the tour page to remove from page ids.
-        """
-        if page_id in self.page_ids:
-            self.page_ids.remove(page_id)
-            if not self.came_back:              # if user is leaving the removed page - moving to the next one
-                self.page_idx -= 1              # .. then correct page index
-
     def reset_app_flow(self):
         """ delayed reset of flow path/id for to be processed after dispatch of popups dismiss. """
         self.main_app.vpo("TourBase.reset_app_flow")
@@ -912,7 +902,7 @@ class TourBase:
 
         main_app.ensure_top_most_z_index(layout)
 
-        self.setup_page_ids()
+        self.update_page_ids()
         main_app.vpo(f"TourBase.setup_layout(): page id={self.page_ids[self.page_idx]}")
 
         self.setup_explained_widget()
@@ -935,10 +925,6 @@ class TourBase:
         app_flow_delay = self.page_data.get('app_flow_delay', 1.2)  # > 0.9 to complete auto width animation
         self.main_app.call_method_delayed(app_flow_delay, self.setup_layout)
 
-    def setup_page_ids(self):
-        """ setup page ids before the tour overlay/layout setup. """
-        self.main_app.vpo(f"TourBase.setup_page_ids ids={self.page_ids}")
-
     def setup_prev_page(self):
         """ setup app flow to display the previous tour page. """
         self.main_app.vpo("TourBase.setup_prev_page")
@@ -989,6 +975,10 @@ class TourBase:
         """ restore tour page state before switch to prev/next page or tour finishing. """
         self.main_app.vpo("TourBase.teardown_page")
 
+    def update_page_ids(self):
+        """ update/change page ids after app flow setup and before the tour overlay/layout setup. """
+        self.main_app.vpo(f"TourBase.update_page_ids ids={self.page_ids}")
+
 
 class TourDropdownFromButton(TourBase):
     """ generic tour base class for to auto-explain a dropdown menu, starting with the button opening the dropdown. """
@@ -1010,23 +1000,24 @@ class TourDropdownFromButton(TourBase):
             if flow_action(prev_page_id) == 'open':
                 self.main_app.popups_opened()[-1].close()
 
-    def setup_page_ids(self):
+    def update_page_ids(self):
         """ prepare all tour pages - first page is explaining opening dropdown button. """
-        super().setup_page_ids()
+        super().update_page_ids()
         page_ids = self.page_ids
         if self.page_idx == 1 and len(page_ids) == 2 and page_ids[1] == TourDropdownFromButton.determine_page_ids:
             popups = self.main_app.popups_opened()
             if not popups:
-                self.main_app.po("TourDropDownFromButton.setup_page_ids: dropdown not opened")
+                self.main_app.po("TourDropDownFromButton.update_page_ids: dropdown not opened")
                 return
 
             children = self.main_app.widget_tourable_children_page_ids(popups[-1])
             if not children:
-                self.main_app.po(f"TourDropDownFromButton.setup_page_ids missing tour-able child in {popups[-1]}")
+                self.main_app.po(f"TourDropDownFromButton.update_page_ids missing tour-able child in {popups[-1]}")
                 return
 
             page_ids.remove(TourDropdownFromButton.determine_page_ids)
             page_ids.extend(children)
+
             self.load_page_data()   # reload page data of this 2nd tour page (explaining the first dropdown child)
 
 
@@ -1048,9 +1039,7 @@ class OnboardingTour(TourBase):
     def setup_page(self):
         """ overridden to open user preferences dropdown in responsible_layout tour page. """
         super().setup_page()
-        page_id = self.page_ids[self.page_idx]
-
-        if page_id == 'layout_font_size':
+        if self.page_ids[self.page_idx] == 'layout_font_size':
             main_app = self.main_app
             flow_id = _OPEN_USER_PREFERENCES_FLOW_ID
             wid = main_app.widget_by_flow_id(flow_id)
@@ -1059,15 +1048,26 @@ class OnboardingTour(TourBase):
     def teardown_page(self):
         """ overridden to close the opened user preferences dropdown on leaving responsible_layout tour page. """
         super().teardown_page()
-        page_id = self.page_ids[self.page_idx]
-
-        if page_id == 'switch_page':
-            self.remove_page('switch_page')
-        elif page_id == 'layout_font_size':
+        if self.page_ids[self.page_idx] == 'layout_font_size':
             popups = self.main_app.popups_opened()
             if popups:
                 popups[-1].close()
 
+    def update_page_ids(self):
+        """ overridden to remove page (only showing once). """
+        super().update_page_ids()
+        try:
+            remove_idx = self.page_ids.index('switch_page')
+        except ValueError:
+            return              # already removed this tour page
+
+        delta_idx = self.page_idx - remove_idx
+        if delta_idx == 1 or (delta_idx == -1 and self.came_back):
+            self.page_ids.remove('switch_page')
+            if delta_idx == 1:
+                self.page_idx -= 1
+                self.load_page_data()   # reload data of the page, situated one idx after the removed page
+
 
 class UserPreferencesTour(TourDropdownFromButton):
     """ user preferences menu tour. """
